@@ -88,7 +88,7 @@ If no found the Keg file, returns nil."
                                   entry-point)))
                    (insert content)
 
-                   (when-let ((scripts (alist-get 'scripts contents)))
+                   (when-let* ((scripts (alist-get 'scripts contents)))
                      (dolist (script scripts)
                        (let* ((cmds (cadr script))
                               (_ (pop cmds))
@@ -96,7 +96,7 @@ If no found the Keg file, returns nil."
                          (insert "(script \"" (eask-2str (car script))
                                  "\" " (prin1-to-string cmds) ")\n"))))
 
-                   (when-let ((sources (alist-get 'sources contents)))
+                   (when-let* ((sources (alist-get 'sources contents)))
                      (insert "\n")
                      (dolist (source sources)
                        (insert "(source '" (eask-2str source) ")\n")))
@@ -106,12 +106,12 @@ If no found the Keg file, returns nil."
                  (unless (alist-get 'packages contents)
                    (insert "\n"))  ; Make sure end line exists!
 
-                 (when-let ((pkgs (alist-get 'packages contents)))
+                 (when-let* ((pkgs (alist-get 'packages contents)))
                    (insert "\n")
                    (dolist (pkg pkgs)
                      (insert "(depends-on \"" (eask-2str (car pkg)) "\")\n")))
 
-                 (when-let ((devs (alist-get 'devs contents)))
+                 (when-let* ((devs (alist-get 'devs contents)))
                    (insert "\n")
                    (insert "(development\n")
                    (dolist (dev devs)
@@ -125,8 +125,8 @@ If no found the Keg file, returns nil."
 
 (eask-start
   ;; Preparation
-  (eask-with-archives "melpa"
-    (eask-package-install 'keg))
+  (eask-archive-install-packages '("gnu" "melpa")
+                                 'keg)
 
   ;; Start Converting
   (require 'keg)
